aboutsummaryrefslogtreecommitdiffstats
path: root/testhal/STM32/STM32F3xx/WDG/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'testhal/STM32/STM32F3xx/WDG/main.c')
-rw-r--r--testhal/STM32/STM32F3xx/WDG/main.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/testhal/STM32/STM32F3xx/WDG/main.c b/testhal/STM32/STM32F3xx/WDG/main.c
index aeec0e35a..5c9cb11a5 100644
--- a/testhal/STM32/STM32F3xx/WDG/main.c
+++ b/testhal/STM32/STM32F3xx/WDG/main.c
@@ -18,10 +18,10 @@
#include "hal.h"
/*
* Watchdog deadline set to one second (LSI=40000 / 4 / 1000).
*/
static const WDGConfig wdgcfg = {
- STM32_IWDG_PR_4,
+ STM32_IWDG_PR_64,
STM32_IWDG_RL(1000),
STM32_IWDG_WIN_DISABLED
};
@@ -18,10 +18,10 @@
#include "hal.h"
/*
- * Watchdog deadline set to one second (LSI=40000 / 4 / 1000).
+ * Watchdog deadline set to more than one second (LSI=40000 / (64 * 1000)).
*/
static const WDGConfig wdgcfg = {